<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../src/clipboard.cpp" line="79"/>
        <source>Copy color %1 to clipboard</source>
        <translation>%1 rengini panoya kopyala</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main.cpp" line="47"/>
        <source>Deepin Picker is a fast screen color picking tool. RGB and HEX code can be obtained according color picked and auto saved to clipboard. The color picking area is where mouse clicked.</source>
        <translation>Deepin Renk Seçici ekrandaki renk kodlarını kolayca almayı sağlayan bir araçtır. Seçilen rengin RGB ve HEX kodları otomatik olarak alınarak panoya kopyalanır. Fare ile tıklanan alandaki renk alınır.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="69"/>
        <source>Deepin Picker</source>
        <translation>Deepin Renk Seçici</translation>
    </message>
</context>
</TS>